@@ -25,6 +25,9 @@
 #include "copy.h"
 #include "mx.h"
 #include "pager.h"
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 
 #ifdef USE_IMAP
 #include "imap.h"
@@ -61,7 +64,10 @@ int mutt_display_message (HEADER *cur)
   char tempfile[_POSIX_PATH_MAX], buf[LONG_STRING];
   int rc = 0, builtin = 0;
   int cmflags = M_CM_DECODE | M_CM_DISPLAY | M_CM_CHARCONV;
-  FILE *fpout;
+  FILE *fpout = NULL;
+  FILE *fpfilterout = NULL;
+  pid_t filterpid = -1;
+  int res;
 
   snprintf (buf, sizeof (buf), "%s/%s", TYPE (cur->content),
 	    cur->content->subtype);
@@ -107,7 +113,23 @@ int mutt_display_message (HEADER *cur)
     return (0);
   }
 
-   mutt_message_hook (cur, M_DISPLAYHOOK);
+  mutt_message_hook (cur, M_MESSAGEHOOK);
+
+  if (DisplayFilter && *DisplayFilter) 
+  {
+    fpfilterout = fpout;
+    fpout = NULL;
+    endwin ();
+    filterpid = mutt_create_filter_fd (DisplayFilter, &fpout, NULL, NULL,
+				       -1, fileno(fpfilterout), -1);
+    if (filterpid < 0)
+    {
+      mutt_error (_("Cannot create display filter"));
+      fclose (fpfilterout);
+      unlink (tempfile);
+      return 0;
+    }
+  }
 
   if (!Pager || mutt_strcmp (Pager, "builtin") == 0)
     builtin = 1;
@@ -118,20 +140,19 @@ int mutt_display_message (HEADER *cur)
     fputs ("\n\n", fpout);
   }
 
-  if (mutt_copy_message (fpout, Context, cur, cmflags,
-			 (option (OPTWEED) ? (CH_WEED | CH_REORDER) : 0) | CH_DECODE | CH_FROM) == -1)
+  res = mutt_copy_message (fpout, Context, cur, cmflags,
+       	(option (OPTWEED) ? (CH_WEED | CH_REORDER) : 0) | CH_DECODE | CH_FROM);
+  if ((fclose (fpout) != 0 && errno != EPIPE) || res == -1)
   {
-    fclose (fpout);
-    unlink (tempfile);
+    mutt_error (_("Could not copy message"));
+    if (fpfilterout != NULL)
+      mutt_wait_filter (filterpid);
+    mutt_unlink (tempfile);
     return 0;
   }
 
-  if (fclose (fpout) != 0 && errno != EPIPE)
-  {
-    mutt_perror ("fclose");
-    mutt_unlink (tempfile);
-    return (0);
-  }
+  if (fpfilterout != NULL && mutt_wait_filter (filterpid) != 0)
+    mutt_any_key_to_continue (NULL);
 
 #ifdef HAVE_PGP
   /* update PGP information for this message */
@@ -143,7 +164,7 @@ int mutt_display_message (HEADER *cur)
     pager_t info;
 
 #ifdef HAVE_PGP
-    if (cur->pgp)
+    if (cmflags & M_CM_VERIFY)
       mutt_message ((cur->pgp & PGPGOODSIGN) ?
 		    _("PGP signature successfully verified.") :
 		    _("PGP signature could NOT be verified."));
@@ -764,10 +785,21 @@ void mutt_version (void)
 void mutt_edit_content_type (HEADER *h, BODY *b)
 {
   char buf[LONG_STRING];
+  char obuf[LONG_STRING];
   char tmp[STRING];
   PARAMETER *p;
+
+  char charset[STRING];
+  char *cp;
+
+  short charset_changed = 0;
+  short type_changed = 0;
   
+  cp = mutt_get_parameter ("charset", b->parameter);
+  strfcpy (charset, NONULL (cp), sizeof (charset));
+
   snprintf (buf, sizeof (buf), "%s/%s", TYPE (b), b->subtype);
+  strfcpy (obuf, buf, sizeof (obuf));
   if (b->parameter)
   {
     size_t l;
@@ -790,9 +822,21 @@ void mutt_edit_content_type (HEADER *h, BODY *b)
   FREE (&b->subtype);
   
   mutt_parse_content_type (buf, b);
+
+  /* inform the user */
   
-  mutt_message ("Content-Type changed to %s/%s.", TYPE (b),
-		NONULL (b->subtype));
+  
+  snprintf (tmp, sizeof (tmp), "%s/%s", TYPE (b), NONULL (b->subtype));
+  type_changed = mutt_strcmp (tmp, obuf);
+  charset_changed = mutt_strcmp (charset, mutt_get_parameter ("charset", b->parameter));
+				 
+  if (type_changed)
+    mutt_message (_("Content-Type changed to %s."), tmp);
+  else if (b->type == TYPETEXT && charset_changed)
+    mutt_message (_("Character set changed to %s."), 
+		  mutt_get_parameter ("charset", b->parameter));
+
+  b->force_charset |= charset_changed;
   
   if (!is_multipart (b) && b->parts)
     mutt_free_body (&b->parts);
