@@ -26,7 +26,6 @@
 #include "mailbox.h"
 #include "sort.h"
 #include "charset.h"
-#include "iconv.h"
 
 #ifdef MIXMASTER
 #include "remailer.h"
@@ -386,33 +385,6 @@ static void update_idx (MUTTMENU *menu, ATTACHPTR **idx, short idxlen)
   return;
 }
 
-static int change_attachment_charset (BODY *b)
-{
-  char buff[SHORT_STRING];
-  iconv_t cd;
-
-  if (!mutt_is_text_type (b->type, b->subtype))
-  {
-    mutt_error _("Can't change character set for non-text attachments!");
-    return 0;
-  }
-
-  mutt_get_send_charset (buff, sizeof(buff), b, 0);
-  
-  if (mutt_get_field (_("Enter character set: "), buff, sizeof(buff), 0) == -1)
-    return 0;
-
-  if ((cd = mutt_iconv_open (buff, "us-ascii")) == (iconv_t)-1)
-  {
-    mutt_error (_("Character set %s is unknown."), buff);
-    return 0;
-  }
-  else
-    iconv_close (cd);
-  
-  mutt_set_body_charset (b, buff);
-  return REDRAW_CURRENT;
-}
 
 /* 
  * cum_attachs_size: Cumulative Attachments Size
@@ -869,11 +841,6 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
         menu->redraw |= REDRAW_STATUS;
 	break;
 
-      case OP_COMPOSE_CHANGE_CHARSET:
-        CHECK_COUNT;
-        menu->redraw = change_attachment_charset(idx[menu->current]->content);
-        break;
-
 #define CURRENT idx[menu->current]->content
       
       case OP_COMPOSE_TOGGLE_RECODE:
@@ -892,38 +859,6 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	menu->redraw = REDRAW_CURRENT;
         break;
       }
-
-      case OP_COMPOSE_RECODE:
-      {
-	const char *chs;
-	int rv;
-
-        CHECK_COUNT;
-        if (!mutt_is_text_type (CURRENT->type, CURRENT->subtype))
-        {
-	  mutt_error (_("Recoding only affects text attachments."));
-	  break;
-	}
-
-	if (!(chs = mutt_get_parameter ("charset", CURRENT->parameter)))
-	  chs = SendCharset;
-
-        if (CURRENT->noconv)
-	  rv = mutt_recode_file (CURRENT->filename, chs, Charset);
-	else
-	  rv = mutt_recode_file (CURRENT->filename, Charset, chs);
-
-	mutt_update_encoding (CURRENT);
-	
-	if (rv == 0)
-	{
-	  mutt_message (_("Recoding successful."));
-	  CURRENT->noconv = !CURRENT->noconv;
-	}
-
-	menu->redraw = REDRAW_CURRENT;
-	break;
-      }
 #undef CURRENT
 
       case OP_COMPOSE_EDIT_DESCRIPTION:
