@@ -224,13 +224,12 @@ struct option_t MuttVars[] = {
   { "autoedit",		DT_BOOL, R_NONE, OPTAUTOEDIT, 0 },
   /*
   ** .pp
-  ** When set, Mutt will skip the initial send-menu and allow you to
-  ** immediately begin editing the body of your message when replying to
-  ** another message.  The send-menu may still be accessed once you have
-  ** finished editing the body of your message.
+  ** When set along with ``$$edit_headers'', Mutt will skip the initial
+  ** send-menu and allow you to immediately begin editing the body of your
+  ** message.  The send-menu may still be accessed once you have finished
+  ** editing the body of your message.
   ** .pp
-  ** If the ``$$edit_headers'' variable is also set, the initial prompts in
-  ** the send-menu are always skipped, even when composing a new message.
+  ** Also see ``$$fast_reply''.
   */
   { "auto_tag",		DT_BOOL, R_NONE, OPTAUTOTAG, 0 },
   /*
@@ -342,7 +341,7 @@ struct option_t MuttVars[] = {
   { "default_hook",	DT_STR,	 R_NONE, UL &DefaultHook, UL "~f %s !~P | (~P ~C %s)" },
   /*
   ** .pp
-  ** This variable controls how send-hooks, display-hooks, save-hooks,
+  ** This variable controls how send-hooks, message-hooks, save-hooks,
   ** and fcc-hooks will
   ** be interpreted if they are specified with only a simple regexp,
   ** instead of a matching pattern.  The hooks are expanded when they are
@@ -368,6 +367,13 @@ struct option_t MuttVars[] = {
   ** for deletion.  This applies when you either explicitly delete a message,
   ** or when you save it to another folder.
   */
+  { "display_filter",	DT_PATH, R_PAGER, UL &DisplayFilter, UL "" },
+  /*
+  ** .pp
+  ** When set, specifies a command used to filter messages.  When a message
+  ** is viewed it is passed as standard input to $$display_filter, and the
+  ** filtered message is read from the standard output.
+  */
 #if defined(DL_STANDALONE) && defined(USE_DOTLOCK)
   { "dotlock_program",  DT_PATH, R_NONE, UL &MuttDotlock, UL BINDIR "/mutt_dotlock" },
   /*
@@ -1733,11 +1739,16 @@ struct option_t MuttVars[] = {
   ** mutt scores are always greater than or equal to zero, the default setting
   ** of this variable will never mark a message read.
   */
-  { "send_charset",	DT_STR,  R_NONE, UL &SendCharset, UL "" },
+  { "send_charset",	DT_STR,  R_NONE, UL &SendCharset, UL "us-ascii:iso-8859-1:utf-8" },
   /*
   ** .pp
-  ** The character set that mutt will use for outgoing messages.
-  ** If this variable is not set, mutt will fall back to ``$$charset''.
+  ** A list of character sets for outgoing messages. Mutt will use the
+  ** first character set into which the text can be converted exactly.
+  ** If your ``$$charset'' is not iso-8859-1 and recipients may not
+  ** understand UTF-8, it is advisable to include in the list an
+  ** appropriate widely used standard character set (such as
+  ** iso-8859-2, koi8-r or iso-2022-jp) either instead of or after
+  ** "iso-8859-1".
   */
   { "sendmail",		DT_PATH, R_NONE, UL &Sendmail, UL SENDMAIL " -oem -oi" },
   /*
@@ -2220,7 +2231,6 @@ struct command_t Commands[] = {
   { "color",		mutt_parse_color,	0 },
   { "uncolor",		mutt_parse_uncolor,	0 },
 #endif
-  { "display-hook",	mutt_parse_hook,	M_DISPLAYHOOK },
   { "exec",		mutt_parse_exec,	0 },
   { "fcc-hook",		mutt_parse_hook,	M_FCCHOOK },
   { "fcc-save-hook",	mutt_parse_hook,	M_FCCHOOK | M_SAVEHOOK },
@@ -2230,6 +2240,7 @@ struct command_t Commands[] = {
   { "lists",		parse_list,		UL &MailLists },
   { "macro",		mutt_parse_macro,	0 },
   { "mailboxes",	mutt_parse_mailboxes,	0 },
+  { "message-hook",	mutt_parse_hook,	M_MESSAGEHOOK },
   { "mbox-hook",	mutt_parse_hook,	M_MBOXHOOK },
   { "mono",		mutt_parse_mono,	0 },
   { "my_hdr",		parse_my_hdr,		0 },
