@@ -130,7 +130,7 @@ typedef enum
 #define M_FCCHOOK	(1<<3)
 #define M_SAVEHOOK	(1<<4)
 #define M_CHARSETHOOK	(1<<5)
-#define M_DISPLAYHOOK	(1<<6)
+#define M_MESSAGEHOOK	(1<<6)
 #ifdef HAVE_PGP
 #define M_PGPHOOK	(1<<7)
 #endif
@@ -544,12 +544,18 @@ typedef struct body
 				 */
   unsigned int tagged : 1;
   unsigned int deleted : 1;	/* attachment marked for deletion */
+
   unsigned int noconv : 1;	/* don't do character set conversion */
+  unsigned int force_charset : 1; 
+  				/* send mode: don't adjust the character
+				 * set when in send-mode.
+				 */
 
 #ifdef HAVE_PGP
   unsigned int goodsig : 1;	/* good PGP signature */
 #endif
 
+
 } BODY;
 
 typedef struct header
