@@ -39,6 +39,10 @@
 #include <errno.h>
 #include <ctype.h>
 
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
+
 #ifdef HAVE_SYS_TIME_H
 # include <sys/time.h>
 #endif
@@ -132,14 +136,13 @@ static void pgp_current_time (STATE *s)
   time_t t;
   char p[STRING];
 
-  state_puts (_("[-- PGP output follows (current time: "), s);
-
   t = time (NULL);
-  strfcpy (p, asctime (localtime (&t)), sizeof (p));
-  p[mutt_strlen (p) - 1] = 0; /* kill the newline */
+  setlocale (LC_TIME, "");
+  strftime (p, sizeof (p),
+	    _("[-- PGP output follows (current time: %c) --]\n"),
+	    localtime (&t));
+  setlocale (LC_TIME, "C");
   state_puts (p, s);
-
-  state_puts (") --]\n", s);
 }
 
 
@@ -551,8 +554,8 @@ static int pgp_verify_one (BODY *sigbdy, STATE *s, const char *tempfile)
   char sigfile[_POSIX_PATH_MAX], pgperrfile[_POSIX_PATH_MAX];
   FILE *fp, *pgpout, *pgperr;
   pid_t thepid;
-  int rv = -1;
-  
+  int badsig = -1;
+
   snprintf (sigfile, sizeof (sigfile), "%s.asc", tempfile);
   
   if(!(fp = safe_fopen (sigfile, "w")))
@@ -579,14 +582,36 @@ static int pgp_verify_one (BODY *sigbdy, STATE *s, const char *tempfile)
 				   -1, -1, fileno(pgperr),
 				   tempfile, sigfile)) != -1)
   {
-    mutt_copy_stream(pgpout, s->fpout);
+    if (PgpGoodSign.pattern)
+    {
+      char *line = NULL;
+      int lineno = 0;
+      size_t linelen;
+
+      while ((line = mutt_read_line (line, &linelen, pgpout, &lineno)) != NULL)
+      {
+	if (regexec (PgpGoodSign.rx, line, 0, NULL, 0) == 0)
+	  badsig = 0;
+
+	fputs (line, s->fpout);
+	fputc ('\n', s->fpout);
+      }
+      safe_free ((void **) &line);
+    }
+    else
+    {
+      mutt_copy_stream(pgpout, s->fpout);
+      badsig = 0;
+    }
+
     fclose (pgpout);
     fflush(pgperr);
     rewind(pgperr);
     mutt_copy_stream(pgperr, s->fpout);
     fclose(pgperr);
     
-    rv = mutt_wait_filter (thepid);
+    if (mutt_wait_filter (thepid))
+      badsig = -1;
   }
   
   state_puts (_("[-- End of PGP output --]\n\n"), s);
@@ -594,7 +619,7 @@ static int pgp_verify_one (BODY *sigbdy, STATE *s, const char *tempfile)
   mutt_unlink (sigfile);
   mutt_unlink (pgperrfile);
 
-  return rv;
+  return badsig;
 }
 
 /*
