@@ -15,7 +15,8 @@
  * 
  *     You should have received a copy of the GNU General Public
  *     License along with this program; if not, write to the Free
- *     Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA. 
+ *     Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *     Boston, MA  02111, USA. 
  */
 
 #include "mutt.h"
@@ -565,6 +566,7 @@ static void attach_forward_msgs (FILE * fp, HEADER * hdr,
     
     if (cur)
     {
+      mutt_message_hook (cur->hdr, M_MESSAGEHOOK);
       mutt_forward_intro (tmpfp, cur->hdr);
       _mutt_copy_message (tmpfp, fp, cur->hdr, cur->hdr->content, cmflags, chflags);
       mutt_forward_trailer (tmpfp);
@@ -575,6 +577,7 @@ static void attach_forward_msgs (FILE * fp, HEADER * hdr,
       {
 	if (idx[i]->content->tagged)
 	{
+	  mutt_message_hook (idx[i]->content->hdr, M_MESSAGEHOOK);
 	  mutt_forward_intro (tmpfp, idx[i]->content->hdr);
 	  _mutt_copy_message (tmpfp, fp, idx[i]->content->hdr,
 			      idx[i]->content->hdr->content, cmflags, chflags);
@@ -730,6 +733,8 @@ static void attach_include_reply (FILE *fp, FILE *tmpfp, HEADER *cur, int flags)
   int cmflags = M_CM_PREFIX | M_CM_DECODE | M_CM_CHARCONV;
   int chflags = CH_DECODE;
 
+  mutt_message_hook (cur, M_MESSAGEHOOK);
+  
   mutt_make_attribution (Context, cur, tmpfp);
   
   if (!option (OPTHEADER))
